==> smartlook-1.0.0.tar.gz: lib/smartlook.dart <==
import 'dart:async';
import 'package:flutter/services.dart';

enum SmartlookNavigationEventType { enter, exit }
enum SmartlookRenderingMode { native, no_rendering }

abstract class IntegrationListener {
    void onSessionReady(String dashboardSessionUrl);
    void onVisitorReady(String dashboardVisitorUrl);
  }

class Smartlook {

	static const MethodChannel _channel =
		const MethodChannel('smartlook');

  static const EventChannel _eventChannel =
    const EventChannel('smartlookEvent');

	static Future<String> get platformVersion async {
		final String version = await _channel.invokeMethod('getPlatformVersion');
    	return version;
	}

// SETUP
	static void setup(String key, [int fps = 2]) async{
    await _channel. invokeMethod('setup',{"key":key, "fps":fps});
  }

	static Future<void> setupAndStartRecording(String key, [int fps = 2]) async{
    await _channel. invokeMethod('setupAndStartRecording',{"key":key, "fps":fps});
  }

  static Future<void> setUserIdentifier(String key, [Object map = null]) async{
    await _channel. invokeMethod('setUserIdentifier',{"key":key, "map":map});
  }

// START & STOP
  static Future<void> startRecording() async{
    await _channel. invokeMethod('startRecording');
  }

  static Future<void> stopRecording() async{
    await _channel. invokeMethod('stopRecording');
  }

  static Future<bool> isRecording() async{
    bool isRecording = await _channel.invokeMethod('isRecording');
    return isRecording;
  }

// EVENTS
  static Future<String> startTimedCustomEvent(String key, [Object map = null]) async{
    String eventId = await _channel. invokeMethod('startTimedCustomEvent',{"key":key, "map":map});
    return eventId;
  }

  static Future<void> stopTimedCustomEvent(String key, [Object map = null]) async{
    await _channel. invokeMethod('stopTimedCustomEvent',{"key":key, "map":map});
  }

  static Future<void> cancelTimedCustomEvent(String key, String reason, [Object map = null]) async{
    await _channel. invokeMethod('cancelTimedCustomEvent',{"key":key, "reason":reason, "map":map});
  }

  static Future<void> trackCustomEvent(String key, [Object map = null]) async{
  	await _channel. invokeMethod('trackCustomEvent',{"key":key, "map":map});
  }
 
  static Future<void> trackNavigationEvent(String key, SmartlookNavigationEventType type) async {
    await _channel. invokeListMethod("trackNavigationEvent", { "key": key, "type" : type.index } );
  }

// SENSITIVE 
  static Future<void> startFullscreenSensitiveMode() async{
    await _channel. invokeMethod('startFullscreenSensitiveMode');
  }

  static Future<void> stopFullscreenSensitiveMode() async{
    await _channel. invokeMethod('stopFullscreenSensitiveMode');
  }

  static Future<bool> isFullscreenSensitiveModeActive() async{
    bool isFullscreenSesitiveMode = await _channel. invokeMethod('isFullscreenSensitiveModeActive');
    return isFullscreenSesitiveMode;
  }

  static Future<void> enableWebviewRecording(bool enabled) async{
  	await _channel. invokeMethod('enableWebviewRecording',{"enabled":enabled});
  }

// GLOBAL EVENT PROPERTIES
  static Future<void> setGlobalEventProperty(String key, String value, bool immutable) async{
    await _channel. invokeMethod('setGlobalEventProperty',{ "key":key, "value": value, "immutable":immutable});
  }

  static Future<void> setGlobalEventProperties(Object map, bool immutable) async{
    await _channel. invokeMethod('setGlobalEventProperties',{"map":map, "immutable":immutable});
  }

  static Future<void> removeGlobalEventProperty(String key) async{
  	await _channel. invokeMethod('removeGlobalEventProperty',{"key":key});
  }

  static Future<void> removeAllGlobalEventProperties() async{
  	await _channel. invokeMethod('removeAllGlobalEventProperties');
  }

// OTHERS
	static Future<void> setReferrer(String referrer, String source) async{
   	await _channel. invokeMethod('setReferrer',{"referrer":referrer, "source":source});
	}

	static Future<String> getDashboardSessionUrl(bool withCurrentTimestamp) async{
   	String url = await _channel.invokeMethod('getDashboardSessionUrl',{"withCurrentTimestamp" : withCurrentTimestamp});
  	return url;
	}

  static Future<String> getDashboardVisitorUrl() async{
    String url = await _channel.invokeMethod('getDashboardVisitorUrl');
    return url;
  }

  static Future<void> enableCrashlytics(bool enabled) async{
    await _channel.invokeMethod('enableCrashlytics',{"enabled":enabled});
  }

  static Future<void> resetSession(bool resetUser) async{
    await _channel.invokeMethod('resetSession',{"resetUser":resetUser});
  }

  static Future<void> setRenderingMode(SmartlookRenderingMode renderingMode) async{
    await _channel.invokeMethod('setRenderingMode',{"renderingMode":renderingMode.index});
  }

  static Future<void> registerIntegrationListener(IntegrationListener integrationListener) async{
    await _eventChannel.receiveBroadcastStream().listen((event) {
      //print(event);
      if (event.contains('visitor')) {
        integrationListener.onVisitorReady(event);
      } else {
        integrationListener.onSessionReady(event);
      }
    });
  }

}

==> smartlook-1.0.3.tar.gz: lib/smartlook.dart <==
import 'dart:async';
import 'package:flutter/services.dart';
import 'dart:convert' show jsonDecode, jsonEncode;

enum SmartlookNavigationEventType { enter, exit }
enum SmartlookRenderingMode { native, no_rendering }

abstract class IntegrationListener {
    void onSessionReady(String dashboardSessionUrl);
    void onVisitorReady(String dashboardVisitorUrl);
  }

class SetupOptionsBuilder {
  String ApiKey;
  int Fps = 2;
  bool StartNewSession = false;
  bool StartNewSessionAndUser = false;

  SetupOptionsBuilder(this.ApiKey);

  SetupOptions build() {
    return SetupOptions._builder(this);
  }
}

class SetupOptions {
  final String ApiKey;
  final int Fps;
  final bool StartNewSession;
  final bool StartNewSessionAndUser;

  SetupOptions._builder(SetupOptionsBuilder builder) : 
    ApiKey = builder.ApiKey,
    Fps = builder.Fps,
    StartNewSession = builder.StartNewSession,
    StartNewSessionAndUser = builder.StartNewSessionAndUser;

  Map<String, dynamic> toJson() =>
    {
      'ApiKey': ApiKey,
      'Fps': Fps,
      'StartNewSession': StartNewSession,
      'StartNewSessionAndUser': StartNewSessionAndUser,
    };
}

class Smartlook {

	static const MethodChannel _channel =
		const MethodChannel('smartlook');

  static const EventChannel _eventChannel =
    const EventChannel('smartlookEvent');

// SETUP
  static void setup(SetupOptions options) async{
    await _channel. invokeMethod('setupBridge',{"options": jsonEncode(options.toJson())});
  }

  static Future<void> setupAndStartRecording(SetupOptions options) async{
    await _channel. invokeMethod('setupAndStartRecordingBridge',{"options": jsonEncode(options.toJson())});
  }

  static Future<void> setUserIdentifier(String key, [Object map = null]) async{
    await _channel. invokeMethod('setUserIdentifier',{"key":key, "map":map});
  }

// START & STOP
  static Future<void> startRecording() async{
    await _channel. invokeMethod('startRecording');
  }

  static Future<void> stopRecording() async{
    await _channel. invokeMethod('stopRecording');
  }

  static Future<bool> isRecording() async{
    bool isRecording = await _channel.invokeMethod('isRecording');
    return isRecording;
  }

// EVENTS
  static Future<String> startTimedCustomEvent(String key, [Object map = null]) async{
    String eventId = await _channel. invokeMethod('startTimedCustomEvent',{"key":key, "map":map});
    return eventId;
  }

  static Future<void> stopTimedCustomEvent(String key, [Object map = null]) async{
    await _channel. invokeMethod('stopTimedCustomEvent',{"key":key, "map":map});
  }

  static Future<void> cancelTimedCustomEvent(String key, String reason, [Object map = null]) async{
    await _channel. invokeMethod('cancelTimedCustomEvent',{"key":key, "reason":reason, "map":map});
  }

  static Future<void> trackCustomEvent(String key, [Object map = null]) async{
  	await _channel. invokeMethod('trackCustomEvent',{"key":key, "map":map});
  }
 
  static Future<void> trackNavigationEvent(String key, SmartlookNavigationEventType type) async {
    await _channel. invokeListMethod("trackNavigationEvent", { "key": key, "type" : type.index } );
  }

// SENSITIVE 
  static Future<void> startFullscreenSensitiveMode() async{
    await _channel. invokeMethod('startFullscreenSensitiveMode');
  }

  static Future<void> stopFullscreenSensitiveMode() async{
    await _channel. invokeMethod('stopFullscreenSensitiveMode');
  }

  static Future<bool> isFullscreenSensitiveModeActive() async{
    bool isFullscreenSesitiveMode = await _channel. invokeMethod('isFullscreenSensitiveModeActive');
    return isFullscreenSesitiveMode;
  }

  static Future<void> enableWebviewRecording(bool enabled) async{
  	await _channel. invokeMethod('enableWebviewRecording',{"enabled":enabled});
  }

// GLOBAL EVENT PROPERTIES
  static Future<void> setGlobalEventProperty(String key, String value, bool immutable) async{
    await _channel. invokeMethod('setGlobalEventProperty',{ "key":key, "value": value, "immutable":immutable});
  }

  static Future<void> setGlobalEventProperties(Object map, bool immutable) async{
    await _channel. invokeMethod('setGlobalEventProperties',{"map":map, "immutable":immutable});
  }

  static Future<void> removeGlobalEventProperty(String key) async{
  	await _channel. invokeMethod('removeGlobalEventProperty',{"key":key});
  }

  static Future<void> removeAllGlobalEventProperties() async{
  	await _channel. invokeMethod('removeAllGlobalEventProperties');
  }

// OTHERS
	static Future<void> setReferrer(String referrer, String source) async{
   	await _channel. invokeMethod('setReferrer',{"referrer":referrer, "source":source});
	}

	static Future<String> getDashboardSessionUrl(bool withCurrentTimestamp) async{
   	String url = await _channel.invokeMethod('getDashboardSessionUrl',{"withCurrentTimestamp" : withCurrentTimestamp});
  	return url;
	}

  static Future<String> getDashboardVisitorUrl() async{
    String url = await _channel.invokeMethod('getDashboardVisitorUrl');
    return url;
  }

  static Future<void> enableCrashlytics(bool enabled) async{
    await _channel.invokeMethod('enableCrashlytics',{"enabled":enabled});
  }

  static Future<void> resetSession(bool resetUser) async{
    await _channel.invokeMethod('resetSession',{"resetUser":resetUser});
  }

  static Future<void> setRenderingMode(SmartlookRenderingMode renderingMode) async{
    await _channel.invokeMethod('setRenderingMode',{"renderingMode":renderingMode.index});
  }

  static Future<void> registerIntegrationListener(IntegrationListener integrationListener) async{
    await _eventChannel.receiveBroadcastStream().listen((event) {
      //print(event);
      if (event.contains('visitor')) {
        integrationListener.onVisitorReady(event);
      } else {
        integrationListener.onSessionReady(event);
      }
    });
  }

}
